@@ -23,7 +23,7 @@
  */
 #ifndef lint
 static const char rcsid[] _U_ =
-    "@(#) $Header: /tcpdump/master/tcpdump/addrtoname.c,v 1.104 2004/03/24 04:13:38 guy Exp $ (LBL)";
+    "@(#) $Header: /tcpdump/master/tcpdump/addrtoname.c,v 1.96.2.6 2004/03/24 04:14:31 guy Exp $ (LBL)";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -486,7 +486,7 @@ etheraddr_string(register const u_char *ep)
 const char *
 linkaddr_string(const u_char *ep, const unsigned int len)
 {
-	register u_int i;
+	register u_int i, j;
 	register char *cp;
 	register struct enamemem *tp;
 
@@ -500,11 +500,13 @@ linkaddr_string(const u_char *ep, const unsigned int len)
 	tp->e_name = cp = (char *)malloc(len*3);
 	if (tp->e_name == NULL)
 		error("linkaddr_string: malloc");
-	*cp++ = hex[*ep >> 4];
+	if ((j = *ep >> 4) != 0)
+		*cp++ = hex[j];
 	*cp++ = hex[*ep++ & 0xf];
 	for (i = len-1; i > 0 ; --i) {
 		*cp++ = ':';
-		*cp++ = hex[*ep >> 4];
+		if ((j = *ep >> 4) != 0)
+			*cp++ = hex[j];
 		*cp++ = hex[*ep++ & 0xf];
 	}
 	*cp = '\0';
