@@ -1,8 +1,8 @@
 /*
  * Copyright (C) 2000, Richard Sharpe
  *
- * This software may be distributed either under the terms of the 
- * BSD-style licence that accompanies tcpdump or under the GNU GPL 
+ * This software may be distributed either under the terms of the
+ * BSD-style licence that accompanies tcpdump or under the GNU GPL
  * version 2 or later.
  *
  * print-beep.c
@@ -10,16 +10,15 @@
  */
 
 #ifndef lint
-static const char rcsid[] =
-  "@(#) $Header: /tcpdump/master/tcpdump/print-beep.c,v 1.1.2.1 2002/07/11 07:47:01 guy Exp $";
+static const char rcsid[] _U_ =
+  "@(#) $Header: /tcpdump/master/tcpdump/print-beep.c,v 1.4.2.2 2003/11/16 08:51:12 guy Exp $";
 #endif
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include <sys/param.h>
-#include <sys/time.h>
+#include <tcpdump-stdinc.h>
 
 #ifdef HAVE_MEMORY_H
 #include <memory.h>
@@ -27,14 +26,13 @@ static const char rcsid[] =
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 
 #include "interface.h"
 #include "extract.h"
 
 /* Check for a string but not go beyond length
  * Return TRUE on match, FALSE otherwise
- * 
+ *
  * Looks at the first few chars up to tl1 ...
  */
 
@@ -68,6 +66,6 @@ beep_print(const u_char *bp, u_int length)
 		printf(" BEEP SEQ");
 	else if (l_strnstart("END", 4, (const char *)bp, length))
 		printf(" BEEP END");
-	else 
+	else
 		printf(" BEEP (payload or undecoded)");
 }
