@@ -30,7 +30,7 @@
 
 #ifndef lint
 static const char rcsid[] _U_ =
-    "@(#) $Header: /tcpdump/master/tcpdump/print-isakmp.c,v 1.48 2004/03/25 03:31:05 mcr Exp $ (LBL)";
+    "@(#) $Header: /tcpdump/master/tcpdump/print-isakmp.c,v 1.36.2.11 2004/03/24 01:32:42 guy Exp $ (LBL)";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -415,10 +415,9 @@ isakmp_attr_print(const u_char *p, const u_char *ep)
 }
 
 static const u_char *
-isakmp_sa_print(const struct isakmp_gen *ext,
-		u_int item_len _U_,
-		const u_char *ep, u_int32_t phase, u_int32_t doi0 _U_,
-		u_int32_t proto0, int depth)
+isakmp_sa_print(const struct isakmp_gen *ext, u_int item_len,
+	const u_char *ep, u_int32_t phase, u_int32_t doi0 _U_,
+	u_int32_t proto0, int depth)
 {
 	const struct isakmp_pl_sa *p;
 	struct isakmp_pl_sa sa;
@@ -476,9 +475,9 @@ trunc:
 }
 
 static const u_char *
-isakmp_p_print(const struct isakmp_gen *ext, u_int item_len _U_,
-	       const u_char *ep, u_int32_t phase, u_int32_t doi0,
-	       u_int32_t proto0 _U_, int depth)
+isakmp_p_print(const struct isakmp_gen *ext, u_int item_len,
+	const u_char *ep, u_int32_t phase, u_int32_t doi0,
+	u_int32_t proto0 _U_, int depth)
 {
 	const struct isakmp_pl_p *p;
 	struct isakmp_pl_p prop;
@@ -634,9 +633,9 @@ trunc:
 }
 
 static const u_char *
-isakmp_ke_print(const struct isakmp_gen *ext, u_int item_len _U_,
-		const u_char *ep _U_, u_int32_t phase _U_, u_int32_t doi _U_,
-		u_int32_t proto _U_, int depth _U_)
+isakmp_ke_print(const struct isakmp_gen *ext, u_int item_len,
+	const u_char *ep, u_int32_t phase _U_, u_int32_t doi _U_,
+	u_int32_t proto _U_, int depth _U_)
 {
 	struct isakmp_gen e;
 
@@ -657,9 +656,9 @@ trunc:
 }
 
 static const u_char *
-isakmp_id_print(const struct isakmp_gen *ext, u_int item_len _U_,
-		const u_char *ep _U_, u_int32_t phase, u_int32_t doi _U_,
-		u_int32_t proto _U_, int depth _U_)
+isakmp_id_print(const struct isakmp_gen *ext, u_int item_len,
+	const u_char *ep, u_int32_t phase, u_int32_t doi _U_,
+	u_int32_t proto _U_, int depth _U_)
 {
 #define USE_IPSECDOI_IN_PHASE1	1
 	const struct isakmp_pl_id *p;
@@ -835,10 +834,9 @@ trunc:
 }
 
 static const u_char *
-isakmp_cert_print(const struct isakmp_gen *ext, u_int item_len _U_,
-		  const u_char *ep _U_, u_int32_t phase _U_,
-		  u_int32_t doi0 _U_,
-		  u_int32_t proto0 _U_, int depth _U_)
+isakmp_cert_print(const struct isakmp_gen *ext, u_int item_len,
+	const u_char *ep, u_int32_t phase _U_, u_int32_t doi0 _U_,
+	u_int32_t proto0 _U_, int depth _U_)
 {
 	const struct isakmp_pl_cert *p;
 	struct isakmp_pl_cert cert;
@@ -867,9 +865,9 @@ trunc:
 }
 
 static const u_char *
-isakmp_cr_print(const struct isakmp_gen *ext, u_int item_len _U_,
-		const u_char *ep _U_, u_int32_t phase _U_, u_int32_t doi0 _U_,
-		u_int32_t proto0 _U_, int depth _U_)
+isakmp_cr_print(const struct isakmp_gen *ext, u_int item_len,
+	const u_char *ep, u_int32_t phase _U_, u_int32_t doi0 _U_,
+	u_int32_t proto0 _U_, int depth _U_)
 {
 	const struct isakmp_pl_cert *p;
 	struct isakmp_pl_cert cert;
@@ -898,9 +896,9 @@ trunc:
 }
 
 static const u_char *
-isakmp_hash_print(const struct isakmp_gen *ext, u_int item_len _U_,
-		  const u_char *ep _U_, u_int32_t phase _U_, u_int32_t doi _U_,
-		  u_int32_t proto _U_, int depth _U_)
+isakmp_hash_print(const struct isakmp_gen *ext, u_int item_len,
+	const u_char *ep, u_int32_t phase _U_, u_int32_t doi _U_,
+	u_int32_t proto _U_, int depth _U_)
 {
 	struct isakmp_gen e;
 
@@ -921,9 +919,9 @@ trunc:
 }
 
 static const u_char *
-isakmp_sig_print(const struct isakmp_gen *ext, u_int item_len _U_,
-		 const u_char *ep _U_, u_int32_t phase _U_, u_int32_t doi _U_,
-		 u_int32_t proto _U_, int depth _U_)
+isakmp_sig_print(const struct isakmp_gen *ext, u_int item_len,
+	const u_char *ep, u_int32_t phase _U_, u_int32_t doi _U_,
+	u_int32_t proto _U_, int depth _U_)
 {
 	struct isakmp_gen e;
 
@@ -944,11 +942,9 @@ trunc:
 }
 
 static const u_char *
-isakmp_nonce_print(const struct isakmp_gen *ext,
-		   u_int item_len _U_,
-		   const u_char *ep _U_,
-		   u_int32_t phase _U_, u_int32_t doi _U_,
-		   u_int32_t proto _U_, int depth _U_)
+isakmp_nonce_print(const struct isakmp_gen *ext, u_int item_len,
+	const u_char *ep, u_int32_t phase _U_, u_int32_t doi _U_,
+	u_int32_t proto _U_, int depth _U_)
 {
 	struct isakmp_gen e;
 
@@ -1108,9 +1104,9 @@ trunc:
 }
 
 static const u_char *
-isakmp_d_print(const struct isakmp_gen *ext, u_int item_len _U_,
-	       const u_char *ep _U_, u_int32_t phase _U_, u_int32_t doi0 _U_,
-	       u_int32_t proto0 _U_, int depth _U_)
+isakmp_d_print(const struct isakmp_gen *ext, u_int item_len,
+	const u_char *ep, u_int32_t phase _U_, u_int32_t doi0 _U_,
+	u_int32_t proto0 _U_, int depth _U_)
 {
 	const struct isakmp_pl_d *p;
 	struct isakmp_pl_d d;
@@ -1151,10 +1147,9 @@ trunc:
 }
 
 static const u_char *
-isakmp_vid_print(const struct isakmp_gen *ext,
-		 u_int item_len _U_, const u_char *ep _U_,
-		 u_int32_t phase _U_, u_int32_t doi _U_,
-		 u_int32_t proto _U_, int depth _U_)
+isakmp_vid_print(const struct isakmp_gen *ext, u_int item_len,
+	const u_char *ep, u_int32_t phase _U_, u_int32_t doi _U_,
+	u_int32_t proto _U_, int depth _U_)
 {
 	struct isakmp_gen e;
 
