@@ -1,6 +1,6 @@
 /*
- * Marko Kiiskila carnil@cs.tut.fi 
- * 
+ * Marko Kiiskila carnil@cs.tut.fi
+ *
  * Tampere University of Technology - Telecommunications Laboratory
  *
  * Permission to use, copy, modify and distribute this
@@ -12,54 +12,69 @@
  * documentation, and that the use of this software is
  * acknowledged in any publications resulting from using
  * the software.
- * 
+ *
  * TUT ALLOWS FREE USE OF THIS SOFTWARE IN ITS "AS IS"
  * CONDITION AND DISCLAIMS ANY LIABILITY OF ANY KIND FOR
  * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS
  * SOFTWARE.
- * 
+ *
  */
 
 #ifndef lint
-static const char rcsid[] =
-    "@(#) $Header: /tcpdump/master/tcpdump/print-lane.c,v 1.11 2000/12/22 22:45:11 guy Exp $ (LBL)";
+static const char rcsid[] _U_ =
+    "@(#) $Header: /tcpdump/master/tcpdump/print-lane.c,v 1.20.2.2 2003/11/16 08:51:31 guy Exp $ (LBL)";
 #endif
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include <sys/param.h>
-#include <sys/time.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-
-
-#include <netinet/in.h>
+#include <tcpdump-stdinc.h>
 
 #include <stdio.h>
 #include <pcap.h>
 
 #include "interface.h"
 #include "addrtoname.h"
+#include "extract.h"
 #include "ether.h"
 #include "lane.h"
 
+static const struct tok lecop2str[] = {
+	{ 0x0001,	"configure request" },
+	{ 0x0101,	"configure response" },
+	{ 0x0002,	"join request" },
+	{ 0x0102,	"join response" },
+	{ 0x0003,	"ready query" },
+	{ 0x0103,	"ready indication" },
+	{ 0x0004,	"register request" },
+	{ 0x0104,	"register response" },
+	{ 0x0005,	"unregister request" },
+	{ 0x0105,	"unregister response" },
+	{ 0x0006,	"ARP request" },
+	{ 0x0106,	"ARP response" },
+	{ 0x0007,	"flush request" },
+	{ 0x0107,	"flush response" },
+	{ 0x0008,	"NARP request" },
+	{ 0x0009,	"topology request" },
+	{ 0,		NULL }
+};
+
 static inline void
-lane_print(register const u_char *bp, int length)
+lane_hdr_print(register const u_char *bp, int length)
 {
 	register const struct lecdatahdr_8023 *ep;
 
 	ep = (const struct lecdatahdr_8023 *)bp;
 	if (qflag)
-		(void)printf("lecid:%d %s %s %d: ",
-			     ntohs(ep->le_header),
+		(void)printf("lecid:%x %s %s %d: ",
+			     EXTRACT_16BITS(&ep->le_header),
 			     etheraddr_string(ep->h_source),
 			     etheraddr_string(ep->h_dest),
 			     length);
 	else
-		(void)printf("lecid:%d %s %s %s %d: ",
-			     ntohs(ep->le_header),
+		(void)printf("lecid:%x %s %s %s %d: ",
+			     EXTRACT_16BITS(&ep->le_header),
 			     etheraddr_string(ep->h_source),
 			     etheraddr_string(ep->h_dest),
 			     etherproto_string(ep->h_type),
@@ -67,56 +82,66 @@ lane_print(register const u_char *bp, int length)
 }
 
 /*
- * This is the top level routine of the printer.  'p' is the points
- * to the ether header of the packet, 'h->tv' is the timestamp,
+ * This is the top level routine of the printer.  'p' points
+ * to the LANE header of the packet, 'h->ts' is the timestamp,
  * 'h->length' is the length of the packet off the wire, and 'h->caplen'
  * is the number of bytes actually captured.
+ *
+ * This assumes 802.3, not 802.5, LAN emulation.
  */
 void
-lane_if_print(u_char *user, const struct pcap_pkthdr *h, const u_char *p)
+lane_print(const u_char *p, u_int length, u_int caplen)
 {
-	int caplen = h->caplen;
-	int length = h->len;
+	struct lane_controlhdr *lec;
 	struct lecdatahdr_8023 *ep;
 	u_short ether_type;
 	u_short extracted_ethertype;
 
-	ts_print(&h->ts);
+	if (caplen < sizeof(struct lane_controlhdr)) {
+		printf("[|lane]");
+		return;
+	}
+
+	lec = (struct lane_controlhdr *)p;
+	if (EXTRACT_16BITS(&lec->lec_header) == 0xff00) {
+		/*
+		 * LE Control.
+		 */
+		printf("lec: proto %x vers %x %s",
+		    lec->lec_proto, lec->lec_vers,
+		    tok2str(lecop2str, "opcode-#%u", EXTRACT_16BITS(&lec->lec_opcode)));
+		return;
+	}
 
 	if (caplen < sizeof(struct lecdatahdr_8023)) {
 		printf("[|lane]");
-		goto out;
+		return;
 	}
 
 	if (eflag)
-		lane_print(p, length);
+		lane_hdr_print(p, length);
 
 	/*
-	 * Some printers want to get back at the ethernet addresses,
-	 * and/or check that they're not walking off the end of the packet.
-	 * Rather than pass them all the way down, we set these globals.
+	 * Go past the LANE header.
 	 */
-	packetp = p;
-	snapend = p + caplen;
-
 	length -= sizeof(struct lecdatahdr_8023);
 	caplen -= sizeof(struct lecdatahdr_8023);
 	ep = (struct lecdatahdr_8023 *)p;
 	p += sizeof(struct lecdatahdr_8023);
 
-	ether_type = ntohs(ep->h_type);
+	ether_type = EXTRACT_16BITS(&ep->h_type);
 
 	/*
 	 * Is it (gag) an 802.3 encapsulation?
 	 */
 	extracted_ethertype = 0;
-	if (ether_type < ETHERMTU) {
+	if (ether_type <= ETHERMTU) {
 		/* Try to print the LLC-layer header & higher layers */
 		if (llc_print(p, length, caplen, ep->h_source, ep->h_dest,
 		    &extracted_ethertype) == 0) {
 			/* ether_type not known, print raw packet */
 			if (!eflag)
-				lane_print((u_char *)ep, length + sizeof(*ep));
+				lane_hdr_print((u_char *)ep, length + sizeof(*ep));
 			if (extracted_ethertype) {
 				printf("(LLC %s) ",
 			       etherproto_string(htons(extracted_ethertype)));
@@ -128,12 +153,16 @@ lane_if_print(u_char *user, const struct pcap_pkthdr *h, const u_char *p)
 	    &extracted_ethertype) == 0) {
 		/* ether_type not known, print raw packet */
 		if (!eflag)
-			lane_print((u_char *)ep, length + sizeof(*ep));
+			lane_hdr_print((u_char *)ep, length + sizeof(*ep));
 		if (!xflag && !qflag)
 			default_print(p, caplen);
 	}
-	if (xflag)
-		default_print(p, caplen);
- out:
-	putchar('\n');
+}
+
+u_int
+lane_if_print(const struct pcap_pkthdr *h, const u_char *p)
+{
+	lane_print(p, h->len, h->caplen);
+
+	return (sizeof(struct lecdatahdr_8023));
 }
