@@ -31,7 +31,7 @@
 
 #ifndef lint
 static const char rcsid[] _U_ =
-    "@(#) $Header: /tcpdump/master/tcpdump/print-ppp.c,v 1.94 2004/03/24 03:30:06 guy Exp $ (LBL)";
+    "@(#) $Header: /tcpdump/master/tcpdump/print-ppp.c,v 1.89.2.3 2004/03/24 03:32:43 guy Exp $ (LBL)";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -54,7 +54,6 @@ static const char rcsid[] _U_ =
 #include "ppp.h"
 #include "chdlc.h"
 #include "ethertype.h"
-#include "oui.h"
 
 /*
  * The following constatns are defined by IANA. Please refer to
@@ -412,9 +411,7 @@ handle_ctrl_proto(u_int proto, const u_char *pptr, int length)
 		printf(", Magic-Num 0x%08x", EXTRACT_32BITS(tptr));
 		tptr += 4;
 		TCHECK2(*tptr, 3);
-		printf(" Vendor: %s (%u)",
-                       tok2str(oui_values,"Unknown",EXTRACT_24BITS(tptr)),
-                       EXTRACT_24BITS(tptr));
+		printf(" OUI 0x%06x", EXTRACT_24BITS(tptr));
 		/* XXX: need to decode Kind and Value(s)? */
 		break;
 	case CPCODES_CONF_REQ:
@@ -519,7 +516,7 @@ print_lcp_config_options(const u_char *p, int length)
 	if (length < len)
 		return 0;
 	if ((opt >= LCPOPT_MIN) && (opt <= LCPOPT_MAX))
-		printf(", %s (%u)", lcpconfopts[opt],opt);
+		printf(", %s ", lcpconfopts[opt]);
 	else {
 		printf(", unknown LCP option 0x%02x", opt);
 		return len;
@@ -529,13 +526,11 @@ print_lcp_config_options(const u_char *p, int length)
 	case LCPOPT_VEXT:
 		if (len >= 6) {
 			TCHECK2(*(p + 2), 3);
-			printf(" Vendor: %s (%u)",
-                               tok2str(oui_values,"Unknown",EXTRACT_24BITS(p+2)),
-                               EXTRACT_24BITS(p+2));
+			printf(" OUI 0x%06x", EXTRACT_24BITS(p+2));
 #if 0
 			TCHECK(p[5]);
-			printf(", kind: 0x%02x", p[5]);
-			printf(", Value: 0x")
+			printf(" kind 0x%02x", p[5]);
+			printf(" val 0x")
 			for (i = 0; i < len - 6; i++) {
 				TCHECK(p[6 + i]);
 				printf("%02x", p[6 + i]);
@@ -552,7 +547,7 @@ print_lcp_config_options(const u_char *p, int length)
 	case LCPOPT_ACCM:
 		if (len == 6) {
 			TCHECK2(*(p + 2), 4);
-			printf(" 0x%08x", EXTRACT_32BITS(p + 2));
+			printf(" %08x", EXTRACT_32BITS(p + 2));
 		}
 		break;
 	case LCPOPT_AP:
@@ -1141,7 +1136,7 @@ ppp_print(register const u_char *p, u_int length)
 	}
 
         if (eflag)
-            printf("%s (0x%04x), length %u: ",
+            printf("PPP-%s (0x%04x), length %u: ",
                    tok2str(ppptype2str, "unknown", proto),
                    proto,
                    olen);
