@@ -30,7 +30,7 @@ static const char copyright[] _U_ =
     "@(#) Copyright (c) 1988, 1989, 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1997, 2000\n\
 The Regents of the University of California.  All rights reserved.\n";
 static const char rcsid[] _U_ =
-    "@(#) $Header: /tcpdump/master/tcpdump/tcpdump.c,v 1.238 2004/03/23 18:57:33 fenner Exp $ (LBL)";
+    "@(#) $Header: /tcpdump/master/tcpdump/tcpdump.c,v 1.216.2.10 2004/03/17 19:47:48 guy Exp $ (LBL)";
 #endif
 
 /*
@@ -56,19 +56,11 @@ extern int SIZE_BUF;
 #define uint UINT
 #endif /* WIN32 */
 
-#ifdef HAVE_SMI_H
-#include <smi.h>
-#endif
-
 #include <pcap.h>
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#ifndef WIN32
-#include <pwd.h>
-#include <grp.h>
-#endif /* WIN32 */
 
 #include "interface.h"
 #include "addrtoname.h"
@@ -80,11 +72,11 @@ extern int SIZE_BUF;
 int dflag;			/* print filter code */
 int eflag;			/* print ethernet header */
 int fflag;			/* don't translate "foreign" IP address */
-static int Lflag;		/* list available data link types and exit */
+int Lflag;			/* list available data link types and exit */
 int nflag;			/* leave addresses as numbers */
 int Nflag;			/* remove domains from printed host names */
-static int Oflag = 1;		/* run filter code optimizer */
-static int pflag;		/* don't go promiscuous */
+int Oflag = 1;			/* run filter code optimizer */
+int pflag;			/* don't go promiscuous */
 int qflag;			/* quick (shorter) output */
 int Rflag = 1;			/* print sequence # field in AH/ESP*/
 int sflag = 0;			/* use the libsmi to translate OIDs */
@@ -95,25 +87,13 @@ int uflag = 0;			/* Print undecoded NFS handles */
 int vflag;			/* verbose */
 int xflag;			/* print packet in hex */
 int Xflag;			/* print packet in ascii as well as hex */
-static off_t Cflag = 0;		/* rotate dump files after this many bytes */
+off_t Cflag = 0;                /* rotate dump files after this many bytes */
 int Aflag = 0;                  /* print packet only in ascii observing LF, CR, TAB, SPACE */
-static int dlt = -1;		/* if != -1, ask libpcap for the DLT it names */
-static int Cflag_count = 0;	/* Keep track of which file number we're writing */
-static int Wflag = 0;		/* recycle output files after this number of files */
-static int WflagChars = 0;
-
-/*
- * Define the maximum number of files for the -C flag, and how many
- * characters can be added to a filename for the -C flag (which
- * should be enough to handle MAX_CFLAG - 1).
- */
-#define MAX_CFLAG	1000000
-#define MAX_CFLAG_CHARS	6
+int dlt = -1;		/* if != -1, ask libpcap for the DLT it names */
 
 const char *dlt_name = NULL;
 
 char *espsecret = NULL;		/* ESP secret key */
-char *tcpmd5secret = NULL;	/* TCP-MD5 secret key */
 
 int packettype;
 
@@ -132,20 +112,11 @@ static void show_dlts_and_exit(pcap_t *pd) __attribute__((noreturn));
 static void print_packet(u_char *, const struct pcap_pkthdr *, const u_char *);
 static void dump_packet_and_trunc(u_char *, const struct pcap_pkthdr *, const u_char *);
 static void dump_packet(u_char *, const struct pcap_pkthdr *, const u_char *);
-static void droproot(const char *, const char *);
 
 #ifdef SIGINFO
 RETSIGTYPE requestinfo(int);
 #endif
 
-#if defined(USE_WIN32_MM_TIMER)
-  #include <MMsystem.h>
-  static UINT timer_id;
-  static void CALLBACK verbose_stats_dump(UINT, UINT, DWORD_PTR, DWORD_PTR, DWORD_PTR);
-#elif defined(HAVE_ALARM)
-  static void verbose_stats_dump(int sig);
-#endif
-
 static void info(int);
 static u_int packets_captured;
 
@@ -235,9 +206,6 @@ static struct printer printers[] = {
 #ifdef DLT_ENC
 	{ enc_if_print, 	DLT_ENC },
 #endif
-#ifdef DLT_SYMANTEC_FIREWALL
-	{ symantec_if_print, 	DLT_SYMANTEC_FIREWALL },
-#endif
 #ifdef DLT_APPLE_IP_OVER_IEEE1394
 	{ ap1394_if_print,	DLT_APPLE_IP_OVER_IEEE1394 },
 #endif
@@ -321,12 +289,6 @@ show_dlts_and_exit(pcap_t *pd)
 #define B_FLAG_USAGE
 #endif /* WIN32 */
 
-#ifdef HAVE_PCAP_FINDALLDEVS
-#ifndef HAVE_PCAP_IF_T
-#undef HAVE_PCAP_FINDALLDEVS
-#endif
-#endif
-
 #ifdef HAVE_PCAP_FINDALLDEVS
 #define D_FLAG	"D"
 #else
@@ -339,70 +301,12 @@ show_dlts_and_exit(pcap_t *pd)
 #define U_FLAG
 #endif
 
-#ifndef WIN32
-/* Drop root privileges and chroot if necessary */
-static void
-droproot(const char *username, const char *chroot_dir)
-{
-	struct passwd *pw = NULL;
-
-	if (chroot_dir && !username) {
-		fprintf(stderr, "Chroot without dropping root is insecure\n");
-		exit(1);
-	}
-	
-	pw = getpwnam(username);
-	if (pw) {
-		if (chroot_dir) {
-			if (chroot(chroot_dir) != 0 || chdir ("/") != 0) {
-				fprintf(stderr, "Couldn't chroot/chdir to '%.64s'\n", chroot_dir);
-				exit(1);
-			}
-		}
-		if (initgroups(pw->pw_name, pw->pw_gid) != 0 || setgid(pw->pw_gid) != 0 ||
-				 setuid(pw->pw_uid) != 0) {
-			fprintf(stderr, "Couldn't change to '%.32s' uid=%d gid=%d\n", username, 
-							pw->pw_uid, pw->pw_gid);
-			exit(1);
-		}
-	}
-	else {
-		fprintf(stderr, "Couldn't find user '%.32s'\n", username);
-		exit(1);
-	}
-}
-#endif /* WIN32 */
-
-static int
-getWflagChars(int x)
-{
-	int c = 0;
-
-	x -= 1;
-	while (x > 0) {
-		c += 1;
-		x /= 10;
-	}
-
-	return c;
-}
-
-
-static void
-MakeFilename(char *buffer, char *orig_name, int cnt, int max_chars)
-{
-	if (cnt == 0 && max_chars == 0)
-		strcpy(buffer, orig_name);
-	else
-		sprintf(buffer, "%s%0*d", orig_name, max_chars, cnt);
-}
-
 int
 main(int argc, char **argv)
 {
 	register int cnt, op, i;
 	bpf_u_int32 localnet, netmask;
-	register char *cp, *infile, *cmdbuf, *device, *RFileName, *WFileName, *WFileNameAlt;
+	register char *cp, *infile, *cmdbuf, *device, *RFileName, *WFileName;
 	pcap_handler callback;
 	int type;
 	struct bpf_program fcode;
@@ -413,8 +317,6 @@ main(int argc, char **argv)
 	struct dump_info dumpinfo;
 	u_char *pcap_userdata;
 	char ebuf[PCAP_ERRBUF_SIZE];
-	char *username = NULL;
-	char *chroot_dir = NULL;
 #ifdef HAVE_PCAP_FINDALLDEVS
 	pcap_if_t *devpointer;
 	int devnum;
@@ -444,7 +346,7 @@ main(int argc, char **argv)
 
 	opterr = 0;
 	while (
-	    (op = getopt(argc, argv, "aA" B_FLAG "c:C:d" D_FLAG "eE:fF:i:lLm:M:nNOpqr:Rs:StT:u" U_FLAG "vw:W:xXy:YZ:")) != -1)
+	    (op = getopt(argc, argv, "aA" B_FLAG "c:C:d" D_FLAG "eE:fF:i:lLm:nNOpqr:Rs:StT:u" U_FLAG "vw:xXy:Y")) != -1)
 		switch (op) {
 
 		case 'a':
@@ -597,14 +499,6 @@ main(int argc, char **argv)
 #endif
 			break;
 
-		case 'M':
-			/* TCP-MD5 shared secret */
-#ifndef HAVE_LIBCRYPTO
-			warning("crypto code not compiled in");
-#endif
-			tcpmd5secret = optarg;
-			break;
-
 		case 'O':
 			Oflag = 0;
 			break;
@@ -686,13 +580,6 @@ main(int argc, char **argv)
 			WFileName = optarg;
 			break;
 
-		case 'W':
-			Wflag = atoi(optarg);
-			if (Wflag < 0) 
-				error("invalid number of output files %s", optarg);
-			WflagChars = getWflagChars(Wflag);
-			break;
-
 		case 'x':
 			++xflag;
 			break;
@@ -723,16 +610,6 @@ main(int argc, char **argv)
 			}
 			break;
 #endif
-		case 'Z':
-			if (optarg) {
-				username = strdup(optarg);
-			}
-			else {
-				usage();
-				/* NOTREACHED */
-			}
-			break;
-
 		default:
 			usage();
 			/* NOTREACHED */
@@ -741,24 +618,6 @@ main(int argc, char **argv)
 	if (tflag > 0)
 		thiszone = gmt2local(0);
 
-#ifdef WITH_CHROOT
-	/* if run as root, prepare for chrooting */
-	if (getuid() == 0 || geteuid() == 0) {
-		/* future extensibility for cmd-line arguments */
-		if (!chroot_dir)
-			chroot_dir = WITH_CHROOT;
-	}
-#endif
-
-#ifdef WITH_USER
-	/* if run as root, prepare for dropping root privileges */
-	if (getuid() == 0 || geteuid() == 0) {
-		/* Run with '-Z root' to restore old behaviour */ 
-		if (!username)
-			username = WITH_USER;
-	}
-#endif
-
 	if (RFileName != NULL) {
 		int dlt;
 		const char *dlt_name;
@@ -773,8 +632,7 @@ main(int argc, char **argv)
 		 * people's trace files (especially if we're set-UID
 		 * root).
 		 */
-		if (setgid(getgid()) != 0 || setuid(getuid()) != 0 )
-			fprintf(stderr, "Warning: setgid/setuid failed !\n");
+		setuid(getuid());
 #endif /* WIN32 */
 		pd = pcap_open_offline(RFileName, ebuf);
 		if (pd == NULL)
@@ -821,13 +679,6 @@ main(int argc, char **argv)
 			error("%s", ebuf);
 		else if (*ebuf)
 			warning("%s", ebuf);
-		/*
-		 * Let user own process after socket has been opened.
-		 */
-#ifndef WIN32
-		if (setgid(getgid()) != 0 || setuid(getuid()) != 0)
-			fprintf(stderr, "Warning: setgid/setuid failed !\n");
-#endif /* WIN32 */
 #ifdef WIN32
 		if(UserBufferSize != 1000000)
 			if(pcap_setbuff(pd, UserBufferSize)==-1){
@@ -865,6 +716,12 @@ main(int argc, char **argv)
 			netmask = 0;
 			warning("%s", ebuf);
 		}
+		/*
+		 * Let user own process after socket has been opened.
+		 */
+#ifndef WIN32
+		setuid(getuid());
+#endif /* WIN32 */
 	}
 	if (infile)
 		cmdbuf = read_infile(infile);
@@ -894,13 +751,7 @@ main(int argc, char **argv)
 	if (pcap_setfilter(pd, &fcode) < 0)
 		error("%s", pcap_geterr(pd));
 	if (WFileName) {
-		pcap_dumper_t *p;
-
-		WFileNameAlt = (char *)malloc(strlen(WFileName) + MAX_CFLAG_CHARS + 1);
-		if (WFileNameAlt == NULL)
-			error("malloc of WFileNameAlt");
-		MakeFilename(WFileNameAlt, WFileName, 0, WflagChars);
-		p = pcap_dump_open(pd, WFileNameAlt);
+		pcap_dumper_t *p = pcap_dump_open(pd, WFileName);
 		if (p == NULL)
 			error("%s", pcap_geterr(pd));
 		if (Cflag != 0) {
@@ -926,36 +777,9 @@ main(int argc, char **argv)
 		callback = print_packet;
 		pcap_userdata = (u_char *)&printinfo;
 	}
-#ifndef WIN32
-	/*
-	 * We cannot do this earlier, because we want to be able to open
-	 * the file (if done) for writing before giving up permissions.
-	 */
-	if (getuid() == 0 || geteuid() == 0) {
-		if (username || chroot_dir)
-			droproot(username, chroot_dir);
-	}
-#endif /* WIN32 */
 #ifdef SIGINFO
 	(void)setsignal(SIGINFO, requestinfo);
 #endif
-
-	if (vflag > 0 && WFileName) {
-		/*
-		 * When capturing to a file, "-v" means tcpdump should,
-		 * every 10 secodns, "v"erbosely report the number of
-		 * packets captured.
-		 */
-#ifdef USE_WIN32_MM_TIMER
-		/* call verbose_stats_dump() each 1000 +/-100msec */
-		timer_id = timeSetEvent(1000, 100, verbose_stats_dump, 0, TIME_PERIODIC);
-		setvbuf(stderr, NULL, _IONBF, 0);
-#elif defined(HAVE_ALARM)
-		(void)setsignal(SIGALRM, verbose_stats_dump);
-		alarm(1);
-#endif
-	}
-
 #ifndef WIN32
 	if (RFileName == NULL) {
 		int dlt;
@@ -1018,14 +842,6 @@ main(int argc, char **argv)
 static RETSIGTYPE
 cleanup(int signo _U_)
 {
-#ifdef USE_WIN32_MM_TIMER
-	if (timer_id)
-		timeKillEvent(timer_id);
-	timer_id = 0;
-#elif defined(HAVE_ALARM)
-	alarm(0);
-#endif
-
 #ifdef HAVE_PCAP_BREAKLOOP
 	/*
 	 * We have "pcap_breakloop()"; use it, so that we do as little
@@ -1082,10 +898,38 @@ info(register int verbose)
 	infoprint = 0;
 }
 
+static void
+reverse(char *s)
+{
+	int i, j, c;
+
+	for (i = 0, j = strlen(s) - 1; i < j; i++, j--) {
+		c = s[i];
+		s[i] = s[j];
+		s[j] = c;
+	}
+}
+
+
+static void
+swebitoa(unsigned int n, char *s)
+{
+	unsigned int i;
+
+	i = 0;
+	do {
+		s[i++] = n % 10 + '0';
+	} while ((n /= 10) > 0);
+
+	s[i] = '\0';
+	reverse(s);
+}
+
 static void
 dump_packet_and_trunc(u_char *user, const struct pcap_pkthdr *h, const u_char *sp)
 {
 	struct dump_info *dump_info;
+	static uint cnt = 2;
 	char *name;
 
 	++packets_captured;
@@ -1104,18 +948,14 @@ dump_packet_and_trunc(u_char *user, const struct pcap_pkthdr *h, const u_char *s
 		 * Close the current file and open a new one.
 		 */
 		pcap_dump_close(dump_info->p);
-		Cflag_count++;
-		if (Wflag > 0) {
-			if (Cflag_count >= Wflag)
-				Cflag_count = 0;
-		} else {
-			if (Cflag_count >= MAX_CFLAG)
-				error("too many output files");
-		}
-		name = (char *)malloc(strlen(dump_info->WFileName) + MAX_CFLAG_CHARS + 1);
+		if (cnt >= 1000)
+			error("too many output files");
+		name = (char *) malloc(strlen(dump_info->WFileName) + 4);
 		if (name == NULL)
 			error("dump_packet_and_trunc: malloc");
-		MakeFilename(name, dump_info->WFileName, Cflag_count, WflagChars);
+		strcpy(name, dump_info->WFileName);
+		swebitoa(cnt, name + strlen(dump_info->WFileName));
+		cnt++;
 		dump_info->p = pcap_dump_open(dump_info->pd, name);
 		free(name);
 		if (dump_info->p == NULL)
@@ -1220,9 +1060,7 @@ print_packet(u_char *user, const struct pcap_pkthdr *h, const u_char *sp)
 	 * "Wpcap_version" information on Windows.
 	 */
 	char WDversion[]="current-cvs.tcpdump.org";
-#if !defined(HAVE_GENERATED_VERSION)
 	char version[]="current-cvs.tcpdump.org";
-#endif
 	char pcap_version[]="current-cvs.tcpdump.org";
 	char Wpcap_version[]="3.0 alpha";
 #endif
@@ -1246,29 +1084,6 @@ RETSIGTYPE requestinfo(int signo _U_)
 }
 #endif
 
-/*
- * Called once each second in verbose mode while dumping to file
- */
-#ifdef USE_WIN32_MM_TIMER
-void CALLBACK verbose_stats_dump (UINT timer_id _U_, UINT msg _U_, DWORD_PTR arg _U_,
-                                  DWORD_PTR dw1 _U_, DWORD_PTR dw2 _U_)
-{
-	struct pcap_stat stat;
-
-	if (infodelay == 0 && pcap_stats(pd, &stat) >= 0)
-		fprintf(stderr, "Got %u\r", packets_captured);
-}
-#elif defined(HAVE_ALARM)
-static void verbose_stats_dump(int sig _U_)
-{
-	struct pcap_stat stat;
-
-	if (infodelay == 0 && pcap_stats(pd, &stat) >= 0)
-		fprintf(stderr, "Got %u\r", packets_captured);
-	alarm(1);
-}
-#endif
-
 static void
 usage(void)
 {
@@ -1296,11 +1111,9 @@ usage(void)
 	(void)fprintf(stderr,
 "Usage: %s [-aAd" D_FLAG "eflLnNOpqRStu" U_FLAG "vxX]" B_FLAG_USAGE " [-c count] [ -C file_size ]\n", program_name);
 	(void)fprintf(stderr,
-"\t\t[ -E algo:secret ] [ -F file ] [ -i interface ] [ -M secret ]\n");
+"\t\t[ -E algo:secret ] [ -F file ] [ -i interface ] [ -r file ]\n");
 	(void)fprintf(stderr,
-"\t\t[ -r file ] [ -s snaplen ] [ -T type ] [ -w file ] [ -W filecount ]\n");
-	(void)fprintf(stderr,
-"\t\t[ -y datalinktype ] [ -Z user ]\n");
+"\t\t[ -s snaplen ] [ -T type ] [ -w file ] [ -y datalinktype ]\n");
 	(void)fprintf(stderr,
 "\t\t[ expression ]\n");
 	exit(1);
